@@ -1,6 +1,6 @@
 package BibTeX::Parser::Author;
 BEGIN {
-  $BibTeX::Parser::Author::VERSION = '0.6';
+  $BibTeX::Parser::Author::VERSION = '0.61';
 }
 
 use warnings;
@@ -65,11 +65,11 @@ sub split {
         if ( $name =~ /\{/ ) {
             my @tokens;
             my $cur_token = '';
-            while ( scalar( $name =~ /\G \s* ( [^,\{]*? ) \s* ( , | \{ | $ ) /xgc ) ) {
-                $cur_token .= $1 . ' ' if $1;
+            while ( scalar( $name =~ /\G \s* ( [^,\{]*? ) ( \s* , \s* | \{ | \s* $ ) /xgc ) ) {
+                $cur_token .= $1 if $1;
                 if ( $2 =~ /\{/ ) {
                     if ( scalar( $name =~ /\G([^\}]*)\}/gc ) ) {
-                        $cur_token .= "{$1} ";
+                        $cur_token .= "{$1}";
                     } else {
                         die "Unmatched brace in name '$name'";
                     }
@@ -95,14 +95,21 @@ sub _split_name_parts {
         return split /\s+/, $name;
     } else {
         my @parts;
-        while ( scalar( $name =~ /\G ( [^\s\{]* ) \s* ( \s+ | \{ | $ ) /xgc ) ) {
-            push @parts, $1 if $1;
+        my $cur_token = '';
+        while ( scalar( $name =~ /\G ( [^\s\{]* ) ( \s+ | \{ | \s* $ ) /xgc ) ) {
+            $cur_token .= $1;
             if ( $2 =~ /\{/ ) {
                 if ( scalar( $name =~ /\G([^\}]*)\}/gc ) ) {
-                    push @parts, $1;
+                    $cur_token .= "{$1}";
                 } else {
                     die "Unmatched brace in name '$name'";
                 }
+            } else {
+                if ( $cur_token =~ /^{(.*)}$/ ) {
+                    $cur_token = $1;
+                }
+                push @parts, $cur_token;
+                $cur_token = '';
             }
         }
         return @parts;
@@ -185,7 +192,7 @@ BibTeX::Parser::Author
 
 =head1 VERSION
 
-version 0.6
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -211,7 +218,7 @@ BibTeX::Author - Contains a single author for a BibTeX document.
 
 =head1 VERSION
 
-version 0.6
+version 0.61
 
 =head1 FUNCTIONS
 
